/*
** File: derror.c  
** Project: ADMXRC3 module driver
** Purpose: OS-independent IOCTL handlers for device error handling.
**
** (C) Copyright Alpha Data 2012
*/

#include <df.h>
#include "device.h"
#include "derror.h"
#include <admxrc3/types.h>

DfIoStatus
ioctlClearDeviceErrors(
	Admxrc3DeviceContext* pDevCtx,
  Admxrc3ClientContext* pClCtx)
{
  if (!pClCtx->bPrivileged) {
    return DfIoStatusError(ADMXRC3_ACCESS_DENIED);
  }

  pDevCtx->coreInterface.pClearErrors(pDevCtx->pCoreContext);

  return DfIoStatusSuccess;
}

DfIoStatus
ioctlGetDeviceStatus(
	Admxrc3DeviceContext* pDevCtx,
  void* pBuffer,
  unsigned int inSize,
  unsigned int outSize)
{
  IOCTLS_ADMXRC3_GETDEVICESTATUS* pIoctl = (IOCTLS_ADMXRC3_GETDEVICESTATUS*)pBuffer;
  CoreDeviceStatus devStatus;

  if (NULL == pIoctl || sizeof(pIoctl->in) != inSize || sizeof(pIoctl->out) != outSize) {
    return DfIoStatusInvalid;
  }

  pDevCtx->coreInterface.pGetDeviceStatus(pDevCtx->pCoreContext, &devStatus);
  pIoctl->out.window = devStatus.window;
  pIoctl->out.dma = devStatus.dmaEngine;
  pIoctl->out.directMaster = devStatus.directMaster;
  pIoctl->out.modelLow = devStatus.model[0];
  pIoctl->out.modelHigh = devStatus.model[1];

  return DfIoStatusSuccess;
}
